@@ -6,9 +6,9 @@ Type annotations for secretsmanager service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_secretsmanager.type_defs import CancelRotateSecretRequestTypeDef
+    from mypy_boto3_secretsmanager.type_defs import CancelRotateSecretRequestRequestTypeDef
 
-    data: CancelRotateSecretRequestTypeDef = {...}
+    data: CancelRotateSecretRequestRequestTypeDef = {...}
     ```
 """
 import sys
@@ -26,69 +26,69 @@ else:
 
 
 __all__ = (
-    "CancelRotateSecretRequestTypeDef",
-    "CancelRotateSecretResponseResponseTypeDef",
-    "CreateSecretRequestTypeDef",
-    "CreateSecretResponseResponseTypeDef",
-    "DeleteResourcePolicyRequestTypeDef",
-    "DeleteResourcePolicyResponseResponseTypeDef",
-    "DeleteSecretRequestTypeDef",
-    "DeleteSecretResponseResponseTypeDef",
-    "DescribeSecretRequestTypeDef",
-    "DescribeSecretResponseResponseTypeDef",
+    "CancelRotateSecretRequestRequestTypeDef",
+    "CancelRotateSecretResponseTypeDef",
+    "CreateSecretRequestRequestTypeDef",
+    "CreateSecretResponseTypeDef",
+    "DeleteResourcePolicyRequestRequestTypeDef",
+    "DeleteResourcePolicyResponseTypeDef",
+    "DeleteSecretRequestRequestTypeDef",
+    "DeleteSecretResponseTypeDef",
+    "DescribeSecretRequestRequestTypeDef",
+    "DescribeSecretResponseTypeDef",
     "FilterTypeDef",
-    "GetRandomPasswordRequestTypeDef",
-    "GetRandomPasswordResponseResponseTypeDef",
-    "GetResourcePolicyRequestTypeDef",
-    "GetResourcePolicyResponseResponseTypeDef",
-    "GetSecretValueRequestTypeDef",
-    "GetSecretValueResponseResponseTypeDef",
-    "ListSecretVersionIdsRequestTypeDef",
-    "ListSecretVersionIdsResponseResponseTypeDef",
-    "ListSecretsRequestTypeDef",
-    "ListSecretsResponseResponseTypeDef",
+    "GetRandomPasswordRequestRequestTypeDef",
+    "GetRandomPasswordResponseTypeDef",
+    "GetResourcePolicyRequestRequestTypeDef",
+    "GetResourcePolicyResponseTypeDef",
+    "GetSecretValueRequestRequestTypeDef",
+    "GetSecretValueResponseTypeDef",
+    "ListSecretVersionIdsRequestRequestTypeDef",
+    "ListSecretVersionIdsResponseTypeDef",
+    "ListSecretsRequestRequestTypeDef",
+    "ListSecretsResponseTypeDef",
     "PaginatorConfigTypeDef",
-    "PutResourcePolicyRequestTypeDef",
-    "PutResourcePolicyResponseResponseTypeDef",
-    "PutSecretValueRequestTypeDef",
-    "PutSecretValueResponseResponseTypeDef",
-    "RemoveRegionsFromReplicationRequestTypeDef",
-    "RemoveRegionsFromReplicationResponseResponseTypeDef",
+    "PutResourcePolicyRequestRequestTypeDef",
+    "PutResourcePolicyResponseTypeDef",
+    "PutSecretValueRequestRequestTypeDef",
+    "PutSecretValueResponseTypeDef",
+    "RemoveRegionsFromReplicationRequestRequestTypeDef",
+    "RemoveRegionsFromReplicationResponseTypeDef",
     "ReplicaRegionTypeTypeDef",
-    "ReplicateSecretToRegionsRequestTypeDef",
-    "ReplicateSecretToRegionsResponseResponseTypeDef",
+    "ReplicateSecretToRegionsRequestRequestTypeDef",
+    "ReplicateSecretToRegionsResponseTypeDef",
     "ReplicationStatusTypeTypeDef",
     "ResponseMetadataTypeDef",
-    "RestoreSecretRequestTypeDef",
-    "RestoreSecretResponseResponseTypeDef",
-    "RotateSecretRequestTypeDef",
-    "RotateSecretResponseResponseTypeDef",
+    "RestoreSecretRequestRequestTypeDef",
+    "RestoreSecretResponseTypeDef",
+    "RotateSecretRequestRequestTypeDef",
+    "RotateSecretResponseTypeDef",
     "RotationRulesTypeTypeDef",
     "SecretListEntryTypeDef",
     "SecretVersionsListEntryTypeDef",
-    "StopReplicationToReplicaRequestTypeDef",
-    "StopReplicationToReplicaResponseResponseTypeDef",
-    "TagResourceRequestTypeDef",
+    "StopReplicationToReplicaRequestRequestTypeDef",
+    "StopReplicationToReplicaResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
     "TagTypeDef",
-    "UntagResourceRequestTypeDef",
-    "UpdateSecretRequestTypeDef",
-    "UpdateSecretResponseResponseTypeDef",
-    "UpdateSecretVersionStageRequestTypeDef",
-    "UpdateSecretVersionStageResponseResponseTypeDef",
-    "ValidateResourcePolicyRequestTypeDef",
-    "ValidateResourcePolicyResponseResponseTypeDef",
+    "UntagResourceRequestRequestTypeDef",
+    "UpdateSecretRequestRequestTypeDef",
+    "UpdateSecretResponseTypeDef",
+    "UpdateSecretVersionStageRequestRequestTypeDef",
+    "UpdateSecretVersionStageResponseTypeDef",
+    "ValidateResourcePolicyRequestRequestTypeDef",
+    "ValidateResourcePolicyResponseTypeDef",
     "ValidationErrorsEntryTypeDef",
 )
 
-CancelRotateSecretRequestTypeDef = TypedDict(
-    "CancelRotateSecretRequestTypeDef",
+CancelRotateSecretRequestRequestTypeDef = TypedDict(
+    "CancelRotateSecretRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
 
-CancelRotateSecretResponseResponseTypeDef = TypedDict(
-    "CancelRotateSecretResponseResponseTypeDef",
+CancelRotateSecretResponseTypeDef = TypedDict(
+    "CancelRotateSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -97,14 +97,14 @@ CancelRotateSecretResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredCreateSecretRequestTypeDef = TypedDict(
-    "_RequiredCreateSecretRequestTypeDef",
+_RequiredCreateSecretRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateSecretRequestRequestTypeDef",
     {
         "Name": str,
     },
 )
-_OptionalCreateSecretRequestTypeDef = TypedDict(
-    "_OptionalCreateSecretRequestTypeDef",
+_OptionalCreateSecretRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateSecretRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
         "Description": str,
@@ -119,14 +119,14 @@ _OptionalCreateSecretRequestTypeDef = TypedDict(
 )
 
 
-class CreateSecretRequestTypeDef(
-    _RequiredCreateSecretRequestTypeDef, _OptionalCreateSecretRequestTypeDef
+class CreateSecretRequestRequestTypeDef(
+    _RequiredCreateSecretRequestRequestTypeDef, _OptionalCreateSecretRequestRequestTypeDef
 ):
     pass
 
 
-CreateSecretResponseResponseTypeDef = TypedDict(
-    "CreateSecretResponseResponseTypeDef",
+CreateSecretResponseTypeDef = TypedDict(
+    "CreateSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -136,15 +136,15 @@ CreateSecretResponseResponseTypeDef = TypedDict(
     },
 )
 
-DeleteResourcePolicyRequestTypeDef = TypedDict(
-    "DeleteResourcePolicyRequestTypeDef",
+DeleteResourcePolicyRequestRequestTypeDef = TypedDict(
+    "DeleteResourcePolicyRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
 
-DeleteResourcePolicyResponseResponseTypeDef = TypedDict(
-    "DeleteResourcePolicyResponseResponseTypeDef",
+DeleteResourcePolicyResponseTypeDef = TypedDict(
+    "DeleteResourcePolicyResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -152,14 +152,14 @@ DeleteResourcePolicyResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredDeleteSecretRequestTypeDef = TypedDict(
-    "_RequiredDeleteSecretRequestTypeDef",
+_RequiredDeleteSecretRequestRequestTypeDef = TypedDict(
+    "_RequiredDeleteSecretRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
-_OptionalDeleteSecretRequestTypeDef = TypedDict(
-    "_OptionalDeleteSecretRequestTypeDef",
+_OptionalDeleteSecretRequestRequestTypeDef = TypedDict(
+    "_OptionalDeleteSecretRequestRequestTypeDef",
     {
         "RecoveryWindowInDays": int,
         "ForceDeleteWithoutRecovery": bool,
@@ -168,14 +168,14 @@ _OptionalDeleteSecretRequestTypeDef = TypedDict(
 )
 
 
-class DeleteSecretRequestTypeDef(
-    _RequiredDeleteSecretRequestTypeDef, _OptionalDeleteSecretRequestTypeDef
+class DeleteSecretRequestRequestTypeDef(
+    _RequiredDeleteSecretRequestRequestTypeDef, _OptionalDeleteSecretRequestRequestTypeDef
 ):
     pass
 
 
-DeleteSecretResponseResponseTypeDef = TypedDict(
-    "DeleteSecretResponseResponseTypeDef",
+DeleteSecretResponseTypeDef = TypedDict(
+    "DeleteSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -184,15 +184,15 @@ DeleteSecretResponseResponseTypeDef = TypedDict(
     },
 )
 
-DescribeSecretRequestTypeDef = TypedDict(
-    "DescribeSecretRequestTypeDef",
+DescribeSecretRequestRequestTypeDef = TypedDict(
+    "DescribeSecretRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
 
-DescribeSecretResponseResponseTypeDef = TypedDict(
-    "DescribeSecretResponseResponseTypeDef",
+DescribeSecretResponseTypeDef = TypedDict(
+    "DescribeSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -224,8 +224,8 @@ FilterTypeDef = TypedDict(
     total=False,
 )
 
-GetRandomPasswordRequestTypeDef = TypedDict(
-    "GetRandomPasswordRequestTypeDef",
+GetRandomPasswordRequestRequestTypeDef = TypedDict(
+    "GetRandomPasswordRequestRequestTypeDef",
     {
         "PasswordLength": int,
         "ExcludeCharacters": str,
@@ -239,23 +239,23 @@ GetRandomPasswordRequestTypeDef = TypedDict(
     total=False,
 )
 
-GetRandomPasswordResponseResponseTypeDef = TypedDict(
-    "GetRandomPasswordResponseResponseTypeDef",
+GetRandomPasswordResponseTypeDef = TypedDict(
+    "GetRandomPasswordResponseTypeDef",
     {
         "RandomPassword": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-GetResourcePolicyRequestTypeDef = TypedDict(
-    "GetResourcePolicyRequestTypeDef",
+GetResourcePolicyRequestRequestTypeDef = TypedDict(
+    "GetResourcePolicyRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
 
-GetResourcePolicyResponseResponseTypeDef = TypedDict(
-    "GetResourcePolicyResponseResponseTypeDef",
+GetResourcePolicyResponseTypeDef = TypedDict(
+    "GetResourcePolicyResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -264,14 +264,14 @@ GetResourcePolicyResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredGetSecretValueRequestTypeDef = TypedDict(
-    "_RequiredGetSecretValueRequestTypeDef",
+_RequiredGetSecretValueRequestRequestTypeDef = TypedDict(
+    "_RequiredGetSecretValueRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
-_OptionalGetSecretValueRequestTypeDef = TypedDict(
-    "_OptionalGetSecretValueRequestTypeDef",
+_OptionalGetSecretValueRequestRequestTypeDef = TypedDict(
+    "_OptionalGetSecretValueRequestRequestTypeDef",
     {
         "VersionId": str,
         "VersionStage": str,
@@ -280,14 +280,14 @@ _OptionalGetSecretValueRequestTypeDef = TypedDict(
 )
 
 
-class GetSecretValueRequestTypeDef(
-    _RequiredGetSecretValueRequestTypeDef, _OptionalGetSecretValueRequestTypeDef
+class GetSecretValueRequestRequestTypeDef(
+    _RequiredGetSecretValueRequestRequestTypeDef, _OptionalGetSecretValueRequestRequestTypeDef
 ):
     pass
 
 
-GetSecretValueResponseResponseTypeDef = TypedDict(
-    "GetSecretValueResponseResponseTypeDef",
+GetSecretValueResponseTypeDef = TypedDict(
+    "GetSecretValueResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -300,14 +300,14 @@ GetSecretValueResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredListSecretVersionIdsRequestTypeDef = TypedDict(
-    "_RequiredListSecretVersionIdsRequestTypeDef",
+_RequiredListSecretVersionIdsRequestRequestTypeDef = TypedDict(
+    "_RequiredListSecretVersionIdsRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
-_OptionalListSecretVersionIdsRequestTypeDef = TypedDict(
-    "_OptionalListSecretVersionIdsRequestTypeDef",
+_OptionalListSecretVersionIdsRequestRequestTypeDef = TypedDict(
+    "_OptionalListSecretVersionIdsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -317,14 +317,15 @@ _OptionalListSecretVersionIdsRequestTypeDef = TypedDict(
 )
 
 
-class ListSecretVersionIdsRequestTypeDef(
-    _RequiredListSecretVersionIdsRequestTypeDef, _OptionalListSecretVersionIdsRequestTypeDef
+class ListSecretVersionIdsRequestRequestTypeDef(
+    _RequiredListSecretVersionIdsRequestRequestTypeDef,
+    _OptionalListSecretVersionIdsRequestRequestTypeDef,
 ):
     pass
 
 
-ListSecretVersionIdsResponseResponseTypeDef = TypedDict(
-    "ListSecretVersionIdsResponseResponseTypeDef",
+ListSecretVersionIdsResponseTypeDef = TypedDict(
+    "ListSecretVersionIdsResponseTypeDef",
     {
         "Versions": List["SecretVersionsListEntryTypeDef"],
         "NextToken": str,
@@ -334,8 +335,8 @@ ListSecretVersionIdsResponseResponseTypeDef = TypedDict(
     },
 )
 
-ListSecretsRequestTypeDef = TypedDict(
-    "ListSecretsRequestTypeDef",
+ListSecretsRequestRequestTypeDef = TypedDict(
+    "ListSecretsRequestRequestTypeDef",
     {
         "MaxResults": int,
         "NextToken": str,
@@ -345,8 +346,8 @@ ListSecretsRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListSecretsResponseResponseTypeDef = TypedDict(
-    "ListSecretsResponseResponseTypeDef",
+ListSecretsResponseTypeDef = TypedDict(
+    "ListSecretsResponseTypeDef",
     {
         "SecretList": List["SecretListEntryTypeDef"],
         "NextToken": str,
@@ -364,15 +365,15 @@ PaginatorConfigTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredPutResourcePolicyRequestTypeDef = TypedDict(
-    "_RequiredPutResourcePolicyRequestTypeDef",
+_RequiredPutResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredPutResourcePolicyRequestRequestTypeDef",
     {
         "SecretId": str,
         "ResourcePolicy": str,
     },
 )
-_OptionalPutResourcePolicyRequestTypeDef = TypedDict(
-    "_OptionalPutResourcePolicyRequestTypeDef",
+_OptionalPutResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalPutResourcePolicyRequestRequestTypeDef",
     {
         "BlockPublicPolicy": bool,
     },
@@ -380,14 +381,14 @@ _OptionalPutResourcePolicyRequestTypeDef = TypedDict(
 )
 
 
-class PutResourcePolicyRequestTypeDef(
-    _RequiredPutResourcePolicyRequestTypeDef, _OptionalPutResourcePolicyRequestTypeDef
+class PutResourcePolicyRequestRequestTypeDef(
+    _RequiredPutResourcePolicyRequestRequestTypeDef, _OptionalPutResourcePolicyRequestRequestTypeDef
 ):
     pass
 
 
-PutResourcePolicyResponseResponseTypeDef = TypedDict(
-    "PutResourcePolicyResponseResponseTypeDef",
+PutResourcePolicyResponseTypeDef = TypedDict(
+    "PutResourcePolicyResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -395,14 +396,14 @@ PutResourcePolicyResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredPutSecretValueRequestTypeDef = TypedDict(
-    "_RequiredPutSecretValueRequestTypeDef",
+_RequiredPutSecretValueRequestRequestTypeDef = TypedDict(
+    "_RequiredPutSecretValueRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
-_OptionalPutSecretValueRequestTypeDef = TypedDict(
-    "_OptionalPutSecretValueRequestTypeDef",
+_OptionalPutSecretValueRequestRequestTypeDef = TypedDict(
+    "_OptionalPutSecretValueRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
         "SecretBinary": Union[bytes, IO[bytes], StreamingBody],
@@ -413,14 +414,14 @@ _OptionalPutSecretValueRequestTypeDef = TypedDict(
 )
 
 
-class PutSecretValueRequestTypeDef(
-    _RequiredPutSecretValueRequestTypeDef, _OptionalPutSecretValueRequestTypeDef
+class PutSecretValueRequestRequestTypeDef(
+    _RequiredPutSecretValueRequestRequestTypeDef, _OptionalPutSecretValueRequestRequestTypeDef
 ):
     pass
 
 
-PutSecretValueResponseResponseTypeDef = TypedDict(
-    "PutSecretValueResponseResponseTypeDef",
+PutSecretValueResponseTypeDef = TypedDict(
+    "PutSecretValueResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -430,16 +431,16 @@ PutSecretValueResponseResponseTypeDef = TypedDict(
     },
 )
 
-RemoveRegionsFromReplicationRequestTypeDef = TypedDict(
-    "RemoveRegionsFromReplicationRequestTypeDef",
+RemoveRegionsFromReplicationRequestRequestTypeDef = TypedDict(
+    "RemoveRegionsFromReplicationRequestRequestTypeDef",
     {
         "SecretId": str,
         "RemoveReplicaRegions": List[str],
     },
 )
 
-RemoveRegionsFromReplicationResponseResponseTypeDef = TypedDict(
-    "RemoveRegionsFromReplicationResponseResponseTypeDef",
+RemoveRegionsFromReplicationResponseTypeDef = TypedDict(
+    "RemoveRegionsFromReplicationResponseTypeDef",
     {
         "ARN": str,
         "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
@@ -456,15 +457,15 @@ ReplicaRegionTypeTypeDef = TypedDict(
     total=False,
 )
 
-_RequiredReplicateSecretToRegionsRequestTypeDef = TypedDict(
-    "_RequiredReplicateSecretToRegionsRequestTypeDef",
+_RequiredReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
+    "_RequiredReplicateSecretToRegionsRequestRequestTypeDef",
     {
         "SecretId": str,
         "AddReplicaRegions": List["ReplicaRegionTypeTypeDef"],
     },
 )
-_OptionalReplicateSecretToRegionsRequestTypeDef = TypedDict(
-    "_OptionalReplicateSecretToRegionsRequestTypeDef",
+_OptionalReplicateSecretToRegionsRequestRequestTypeDef = TypedDict(
+    "_OptionalReplicateSecretToRegionsRequestRequestTypeDef",
     {
         "ForceOverwriteReplicaSecret": bool,
     },
@@ -472,14 +473,15 @@ _OptionalReplicateSecretToRegionsRequestTypeDef = TypedDict(
 )
 
 
-class ReplicateSecretToRegionsRequestTypeDef(
-    _RequiredReplicateSecretToRegionsRequestTypeDef, _OptionalReplicateSecretToRegionsRequestTypeDef
+class ReplicateSecretToRegionsRequestRequestTypeDef(
+    _RequiredReplicateSecretToRegionsRequestRequestTypeDef,
+    _OptionalReplicateSecretToRegionsRequestRequestTypeDef,
 ):
     pass
 
 
-ReplicateSecretToRegionsResponseResponseTypeDef = TypedDict(
-    "ReplicateSecretToRegionsResponseResponseTypeDef",
+ReplicateSecretToRegionsResponseTypeDef = TypedDict(
+    "ReplicateSecretToRegionsResponseTypeDef",
     {
         "ARN": str,
         "ReplicationStatus": List["ReplicationStatusTypeTypeDef"],
@@ -510,15 +512,15 @@ ResponseMetadataTypeDef = TypedDict(
     },
 )
 
-RestoreSecretRequestTypeDef = TypedDict(
-    "RestoreSecretRequestTypeDef",
+RestoreSecretRequestRequestTypeDef = TypedDict(
+    "RestoreSecretRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
 
-RestoreSecretResponseResponseTypeDef = TypedDict(
-    "RestoreSecretResponseResponseTypeDef",
+RestoreSecretResponseTypeDef = TypedDict(
+    "RestoreSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -526,14 +528,14 @@ RestoreSecretResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredRotateSecretRequestTypeDef = TypedDict(
-    "_RequiredRotateSecretRequestTypeDef",
+_RequiredRotateSecretRequestRequestTypeDef = TypedDict(
+    "_RequiredRotateSecretRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
-_OptionalRotateSecretRequestTypeDef = TypedDict(
-    "_OptionalRotateSecretRequestTypeDef",
+_OptionalRotateSecretRequestRequestTypeDef = TypedDict(
+    "_OptionalRotateSecretRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
         "RotationLambdaARN": str,
@@ -543,14 +545,14 @@ _OptionalRotateSecretRequestTypeDef = TypedDict(
 )
 
 
-class RotateSecretRequestTypeDef(
-    _RequiredRotateSecretRequestTypeDef, _OptionalRotateSecretRequestTypeDef
+class RotateSecretRequestRequestTypeDef(
+    _RequiredRotateSecretRequestRequestTypeDef, _OptionalRotateSecretRequestRequestTypeDef
 ):
     pass
 
 
-RotateSecretResponseResponseTypeDef = TypedDict(
-    "RotateSecretResponseResponseTypeDef",
+RotateSecretResponseTypeDef = TypedDict(
+    "RotateSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -601,23 +603,23 @@ SecretVersionsListEntryTypeDef = TypedDict(
     total=False,
 )
 
-StopReplicationToReplicaRequestTypeDef = TypedDict(
-    "StopReplicationToReplicaRequestTypeDef",
+StopReplicationToReplicaRequestRequestTypeDef = TypedDict(
+    "StopReplicationToReplicaRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
 
-StopReplicationToReplicaResponseResponseTypeDef = TypedDict(
-    "StopReplicationToReplicaResponseResponseTypeDef",
+StopReplicationToReplicaResponseTypeDef = TypedDict(
+    "StopReplicationToReplicaResponseTypeDef",
     {
         "ARN": str,
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
 
-TagResourceRequestTypeDef = TypedDict(
-    "TagResourceRequestTypeDef",
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
     {
         "SecretId": str,
         "Tags": List["TagTypeDef"],
@@ -633,22 +635,22 @@ TagTypeDef = TypedDict(
     total=False,
 )
 
-UntagResourceRequestTypeDef = TypedDict(
-    "UntagResourceRequestTypeDef",
+UntagResourceRequestRequestTypeDef = TypedDict(
+    "UntagResourceRequestRequestTypeDef",
     {
         "SecretId": str,
         "TagKeys": List[str],
     },
 )
 
-_RequiredUpdateSecretRequestTypeDef = TypedDict(
-    "_RequiredUpdateSecretRequestTypeDef",
+_RequiredUpdateSecretRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSecretRequestRequestTypeDef",
     {
         "SecretId": str,
     },
 )
-_OptionalUpdateSecretRequestTypeDef = TypedDict(
-    "_OptionalUpdateSecretRequestTypeDef",
+_OptionalUpdateSecretRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSecretRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
         "Description": str,
@@ -660,14 +662,14 @@ _OptionalUpdateSecretRequestTypeDef = TypedDict(
 )
 
 
-class UpdateSecretRequestTypeDef(
-    _RequiredUpdateSecretRequestTypeDef, _OptionalUpdateSecretRequestTypeDef
+class UpdateSecretRequestRequestTypeDef(
+    _RequiredUpdateSecretRequestRequestTypeDef, _OptionalUpdateSecretRequestRequestTypeDef
 ):
     pass
 
 
-UpdateSecretResponseResponseTypeDef = TypedDict(
-    "UpdateSecretResponseResponseTypeDef",
+UpdateSecretResponseTypeDef = TypedDict(
+    "UpdateSecretResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -676,15 +678,15 @@ UpdateSecretResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredUpdateSecretVersionStageRequestTypeDef = TypedDict(
-    "_RequiredUpdateSecretVersionStageRequestTypeDef",
+_RequiredUpdateSecretVersionStageRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateSecretVersionStageRequestRequestTypeDef",
     {
         "SecretId": str,
         "VersionStage": str,
     },
 )
-_OptionalUpdateSecretVersionStageRequestTypeDef = TypedDict(
-    "_OptionalUpdateSecretVersionStageRequestTypeDef",
+_OptionalUpdateSecretVersionStageRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateSecretVersionStageRequestRequestTypeDef",
     {
         "RemoveFromVersionId": str,
         "MoveToVersionId": str,
@@ -693,14 +695,15 @@ _OptionalUpdateSecretVersionStageRequestTypeDef = TypedDict(
 )
 
 
-class UpdateSecretVersionStageRequestTypeDef(
-    _RequiredUpdateSecretVersionStageRequestTypeDef, _OptionalUpdateSecretVersionStageRequestTypeDef
+class UpdateSecretVersionStageRequestRequestTypeDef(
+    _RequiredUpdateSecretVersionStageRequestRequestTypeDef,
+    _OptionalUpdateSecretVersionStageRequestRequestTypeDef,
 ):
     pass
 
 
-UpdateSecretVersionStageResponseResponseTypeDef = TypedDict(
-    "UpdateSecretVersionStageResponseResponseTypeDef",
+UpdateSecretVersionStageResponseTypeDef = TypedDict(
+    "UpdateSecretVersionStageResponseTypeDef",
     {
         "ARN": str,
         "Name": str,
@@ -708,14 +711,14 @@ UpdateSecretVersionStageResponseResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredValidateResourcePolicyRequestTypeDef = TypedDict(
-    "_RequiredValidateResourcePolicyRequestTypeDef",
+_RequiredValidateResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_RequiredValidateResourcePolicyRequestRequestTypeDef",
     {
         "ResourcePolicy": str,
     },
 )
-_OptionalValidateResourcePolicyRequestTypeDef = TypedDict(
-    "_OptionalValidateResourcePolicyRequestTypeDef",
+_OptionalValidateResourcePolicyRequestRequestTypeDef = TypedDict(
+    "_OptionalValidateResourcePolicyRequestRequestTypeDef",
     {
         "SecretId": str,
     },
@@ -723,14 +726,15 @@ _OptionalValidateResourcePolicyRequestTypeDef = TypedDict(
 )
 
 
-class ValidateResourcePolicyRequestTypeDef(
-    _RequiredValidateResourcePolicyRequestTypeDef, _OptionalValidateResourcePolicyRequestTypeDef
+class ValidateResourcePolicyRequestRequestTypeDef(
+    _RequiredValidateResourcePolicyRequestRequestTypeDef,
+    _OptionalValidateResourcePolicyRequestRequestTypeDef,
 ):
     pass
 
 
-ValidateResourcePolicyResponseResponseTypeDef = TypedDict(
-    "ValidateResourcePolicyResponseResponseTypeDef",
+ValidateResourcePolicyResponseTypeDef = TypedDict(
+    "ValidateResourcePolicyResponseTypeDef",
     {
         "PolicyValidationPassed": bool,
         "ValidationErrors": List["ValidationErrorsEntryTypeDef"],
